@@ -9,9 +9,10 @@ def line_plot(
     ylabel=None,
     show=None,
     path=None,
+    transparent=True,
+    dpi=60,
     palette="mako_r",
 ):
-    """Produces a line plot based on a dictionary of metrics and labels."""
     import seaborn as sns
 
     if show and path is not None:
